import _mergeJSXProps from 'babel-helper-vue-jsx-merge-props';
import ListItem from '../list-item';
import Icon from '../icon';
import ListItemMixin from '../mixins/list-item';
import { doubleRaf } from '../_utils/dom/raf';
import './index.less';

var CollapsePanel = {
    name: "CollapsePanel",
    mixins: [ListItemMixin],
    components: {
        Icon: Icon
    },
    data: function data() {
        return {
            show: null
        };
    },

    props: {
        name: [String, Number],
        clickable: {
            type: Boolean,
            'default': true
        }
    },
    computed: {
        expanded: function expanded() {
            var _this = this;

            if (!this.$parent) {
                return null;
            }
            var _$parent = this.$parent,
                _$parent$value = _$parent.value,
                value = _$parent$value === undefined ? [] : _$parent$value,
                accordion = _$parent.accordion;

            return accordion ? value === this.name : value.some(function (name) {
                return name === _this.name;
            });
        }
    },
    created: function created() {
        this.show = this.expanded;
    },

    methods: {
        handleItemClick: function handleItemClick() {
            var $parent = this.$parent;

            var name = $parent.accordion && this.name === $parent.value ? '' : this.name;
            this.$parent['switch'](name, !this.expanded);
        },
        onTransitionEnd: function onTransitionEnd() {
            if (!this.expanded) {
                this.show = false;
            } else {
                this.$refs.wrapper.style.height = '';
            }
        }
    },
    watch: {
        expanded: function expanded(newVal, oldVal) {
            var _this2 = this;

            if (oldVal === null) {
                return;
            }
            if (newVal) {
                this.show = true;
            }

            this.$nextTick(function () {
                var _$refs = _this2.$refs,
                    wrapper = _$refs.wrapper,
                    content = _$refs.content;

                if (!wrapper || !content) return;
                var offsetHeight = content.offsetHeight;


                if (offsetHeight) {
                    wrapper.style.height = newVal ? 0 : offsetHeight + 'px';

                    doubleRaf(function () {
                        wrapper.style.height = newVal ? offsetHeight + 'px' : 0;
                    });
                } else {
                    _this2.onTransitionEnd();
                }
            });
        }
    },
    render: function render() {
        var h = arguments[0];
        var show = this.show,
            expanded = this.expanded,
            $slots = this.$slots;


        var panelCls = {
            'sn-collapse-panel': true,
            'sn-collapse-panel-expanded': expanded
        };

        return h(
            'div',
            {
                'class': panelCls
            },
            [h(
                ListItem,
                _mergeJSXProps([{
                    attrs: {
                        role: 'button',
                        tabindex: 0,
                        'aria-expanded': String(expanded)
                    }
                }, { props: this.$props }, {
                    attrs: {
                        border: expanded
                    },
                    'class': 'sn-collapse-panel-header',
                    on: {
                        'click': this.handleItemClick
                    }
                }]),
                [$slots.value ? h(
                    'div',
                    { slot: 'default', 'class': 'sn-collapse-panel-header-content' },
                    [$slots.value]
                ) : null, h(Icon, {
                    attrs: { type: 'down' },
                    slot: 'right-icon', 'class': 'sn-collapse-panel-header-arrow' })]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'show',
                        value: show
                    }],

                    ref: 'wrapper',
                    'class': 'sn-collapse-panel-body',
                    on: {
                        'transitionend': this.onTransitionEnd
                    }
                },
                [h(
                    'div',
                    { ref: 'content', 'class': 'sn-collapse-panel-content' },
                    [$slots['default']]
                )]
            )]
        );
    }
};

export default CollapsePanel;