import ListItem from '../list-item';
import Icon from '../icon';
import Popup from '../popup';
import { PortalMixin } from '../mixins/portal';
import { ChildrenMixin } from '../mixins/relation';

var DropdownMenuItem = {
    mixins: [PortalMixin({ ref: 'wrapper' }), ChildrenMixin('snDropdownMenu')],

    props: {
        value: null,
        title: String,
        disabled: Boolean,
        titleClass: String,
        options: {
            type: Array,
            'default': function _default() {
                return [];
            }
        }
    },

    data: function data() {
        return {
            transition: true,
            showPopup: false,
            showWrapper: false
        };
    },


    computed: {
        displayTitle: function displayTitle() {
            var _this = this;

            if (this.title) {
                return this.title;
            }

            var match = this.options.filter(function (option) {
                return option.value === _this.value;
            });
            return match.length ? match[0].text : '';
        }
    },

    methods: {
        toggle: function toggle() {
            var show = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : !this.showPopup;
            var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

            if (show === this.showPopup) {
                return;
            }

            this.transition = !options.immediate;
            this.showPopup = show;

            if (show) {
                this.parent.updateOffset();
                this.showWrapper = true;
            }
        }
    },

    beforeCreate: function beforeCreate() {
        var _this2 = this;

        var createEmitter = function createEmitter(eventName) {
            return function () {
                return _this2.$emit(eventName);
            };
        };

        this.onOpen = createEmitter('open');
        this.onClose = createEmitter('close');
        this.onOpened = createEmitter('opened');
    },
    render: function render() {
        var _this3 = this;

        var h = arguments[0];
        var _$parent = this.$parent,
            zIndex = _$parent.zIndex,
            offset = _$parent.offset,
            overlay = _$parent.overlay,
            duration = _$parent.duration,
            direction = _$parent.direction,
            activeColor = _$parent.activeColor,
            closeOnClickOverlay = _$parent.closeOnClickOverlay;


        var Options = this.options.map(function (option) {
            var active = option.value === _this3.value;
            return h(
                ListItem,
                {
                    attrs: {
                        clickable: true,

                        icon: option.icon,
                        title: option.text
                    },
                    key: option.value, 'class': {
                        'sn-dropdown-menu-item-option': true,
                        'sn-dropdown-menu-item-option-active': active
                    },
                    style: { color: active ? activeColor : '' },
                    on: {
                        'click': function click() {
                            _this3.showPopup = false;

                            if (option.value !== _this3.value) {
                                _this3.$emit('input', option.value);
                                _this3.$emit('change', option.value);
                            }
                        }
                    }
                },
                [active && h(Icon, { 'class': 'sn-dropdown-menu-item-icon', attrs: { color: activeColor, type: 'success' }
                })]
            );
        });

        var style = { zIndex: zIndex };
        if (direction === 'down') {
            style.top = offset + 'px';
        } else {
            style.bottom = offset + 'px';
        }

        return h('div', [h(
            'div',
            {
                directives: [{
                    name: 'show',
                    value: this.showWrapper
                }],

                ref: 'wrapper',
                style: style,
                'class': '' + direction
            },
            [h(
                Popup,
                {
                    attrs: {
                        vModel: this.showPopup,
                        overlay: overlay,

                        position: direction === 'down' ? 'top' : 'bottom',
                        duration: this.transition ? duration : 0,
                        closeOnClickOverlay: closeOnClickOverlay,
                        overlayStyle: { position: 'absolute' }
                    },
                    'class': 'sn-dropdown-menu-item-content', on: {
                        'open': this.onOpen,
                        'close': this.onClose,
                        'opened': this.onOpened,
                        'closed': function closed() {
                            _this3.showWrapper = false;
                            _this3.$emit('closed');
                        }
                    }
                },
                [Options, this.$slots['default']]
            )]
        )]);
    }
};

export default DropdownMenuItem;