import { ParentMixin } from '../mixins/relation';
// import { ClickOutsideMixin } from '../mixins/click-outside';
import classNames from '../_utils/classnames';
import './index.less';

var DropdownMenu = {
    mixins: [ParentMixin('snDropdownMenu')
    // ClickOutsideMixin({
    //     event: 'click',
    //     method: 'onClickOutside'
    // })
    ],

    props: {
        activeColor: String,
        overlay: {
            type: Boolean,
            'default': true
        },
        zIndex: {
            type: Number,
            'default': 10
        },
        duration: {
            type: Number,
            'default': 0.2
        },
        direction: {
            type: String,
            'default': 'down'
        },
        closeOnClickOverlay: {
            type: Boolean,
            'default': true
        }
    },

    data: function data() {
        return {
            offset: 0
        };
    },


    methods: {
        updateOffset: function updateOffset() {
            var menu = this.$refs.menu;

            var rect = menu.getBoundingClientRect();

            if (this.direction === 'down') {
                this.offset = rect.bottom;
            } else {
                this.offset = window.innerHeight - rect.top;
            }
        },
        toggleItem: function toggleItem(active) {
            this.children.forEach(function (item, index) {
                if (index === active) {
                    item.toggle();
                } else if (item.showPopup) {
                    item.toggle(false, { immediate: true });
                }
            });
        },
        onClickOutside: function onClickOutside() {
            this.children.forEach(function (item) {
                item.toggle(false);
            });
        }
    },

    render: function render() {
        var _this = this;

        var h = arguments[0];

        var Titles = this.children.map(function (item, index) {
            return h(
                'div',
                {
                    attrs: {
                        role: 'button',
                        tabindex: item.disabled ? -1 : 0
                    },
                    'class': {
                        'sn-dropdown-menu-item': true,
                        'sn-dropdown-menu-disabled': item.disabled
                    },
                    on: {
                        'click': function click() {
                            if (!item.disabled) {
                                _this.toggleItem(index);
                            }
                        }
                    }
                },
                [h(
                    'span',
                    {
                        'class': classNames({
                            'sn-dropdown-menu-title': true,
                            'sn-dropdown-menu-title-active': item.showPopup,
                            'sn-dropdown-menu-title-down': item.showPopup === (_this.direction === 'down')
                        }, item.titleClass),
                        style: { color: item.showPopup ? _this.activeColor : '' }
                    },
                    [h(
                        'div',
                        { 'class': 'sn-ellipsis' },
                        [item.displayTitle]
                    )]
                )]
            );
        });

        return h(
            'div',
            { ref: 'menu', 'class': 'sn-dropdown-menu' },
            [Titles, this.slots('default')]
        );
    }
};

export default DropdownMenu;