import { PopupMixin } from '../mixins/popup';
import { isPC, isDef } from '../utils/commonUtil';
import './index.less';

var Popup = {
    mixins: [PopupMixin],
    data: function data() {
        return {
            inited: this.value,
            currentValue: false
        };
    },

    props: {
        value: Boolean,
        overlay: {
            type: Boolean,
            'default': true
        },
        position: {
            type: String,
            'default': 'bottom'
        },
        overlayStyle: Object,
        duration: [Number, String]
    },
    watch: {
        value: function value(val) {
            var _this = this;

            console.log('popup watch value');
            if (val) {
                var activeTagName = window.activeTagName || '';

                if (!isPC() && activeTagName.toUpperCase() === 'INPUT' || activeTagName.toUpperCase() === 'TEXTAREA') {
                    setTimeout(function () {
                        _this.currentValue = true;
                    }, 300);
                } else {
                    this.currentValue = true;
                }
            } else {
                this.currentValue = false;
            }
        }
    },
    beforeCreate: function beforeCreate() {
        var _this2 = this;

        var createEmitter = function createEmitter(eventName) {
            return function (event) {
                return _this2.$emit(eventName, event);
            };
        };

        this.onClick = createEmitter('click');
        this.onOpened = createEmitter('opened');
        this.onClosed = createEmitter('closed');
    },

    methods: {},
    render: function render() {
        var h = arguments[0];

        if (!this.shouldRender) {
            return;
        }
        var value = this.value,
            currentValue = this.currentValue,
            position = this.position,
            duration = this.duration,
            $slots = this.$slots;

        var transitionName = position === 'center' ? 'sn-fade' : 'sn-popup-slide-' + position;
        var style = {};
        if (isDef(duration)) {
            style.animationDuration = duration + 'ms';
        }
        var className = {
            'sn-popup': true
        };
        className['sn-popup-' + position] = true;

        var children = null;
        if (value && currentValue || !value && !currentValue) {
            children = $slots['default'];
        }

        return h(
            'transition',
            {
                attrs: { name: transitionName }
            },
            [h(
                'div',
                {
                    directives: [{
                        name: 'show',
                        value: currentValue
                    }],

                    style: style,
                    'class': className,
                    on: {
                        'click': this.onClick
                    }
                },
                [children]
            )]
        );
    }
};

export default Popup;