import _extends from 'babel-runtime/helpers/extends';
import Vue from 'vue';
import VueToast from './toast';
import { isObj } from '../utils/commonUtil';

var defaultOptions = {
    icon: '',
    type: 'text',
    mask: false,
    value: true,
    message: '',
    className: '',
    onClose: null,
    onOpened: null,
    duration: 2000,
    iconPrefix: undefined,
    position: 'middle',
    transition: 'sn-fade',
    forbidClick: false,
    loadingType: undefined,
    getContainer: 'body',
    overlayStyle: null,
    closeOnClick: false
};

// default options of specific type
var defaultOptionsMap = {};

var queue = [];
var multiple = false;
var currentOptions = _extends({}, defaultOptions);

function parseOptions(message) {
    if (isObj(message)) {
        return message;
    }

    return { message: message };
}

function createInstance() {
    if (!queue.length || multiple) {
        var toast = new (Vue.extend(VueToast))({
            el: document.createElement('div')
        });

        toast.$on('input', function (value) {
            toast.value = value;
        });

        queue.push(toast);
    }

    return queue[queue.length - 1];
}

// transform toast options to popup props
function transformOptions(options) {
    options = _extends({}, options);
    options.overlay = options.mask;

    delete options.mask;
    delete options.duration;

    return options;
}

function Toast() {
    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var toast = createInstance();

    // should add z-index if previous toast has not disappeared
    if (toast.value) {
        toast.updateZIndex();
    }

    options = parseOptions(options);
    options = _extends({}, currentOptions, defaultOptionsMap[options.type || currentOptions.type], options);

    options.clear = function () {
        toast.value = false;

        if (options.onClose) {
            options.onClose();
        }

        if (multiple) {
            toast.$on('closed', function () {
                clearTimeout(toast.timer);
                queue = queue.filter(function (item) {
                    return item !== toast;
                });

                var parent = toast.$el.parentNode;
                if (parent) {
                    parent.removeChild(toast.$el);
                }

                toast.$destroy();
            });
        }
    };

    _extends(toast, transformOptions(options));
    clearTimeout(toast.timer);

    if (options.duration > 0) {
        toast.timer = setTimeout(function () {
            toast.clear();
        }, options.duration);
    }

    return toast;
}

var createMethod = function createMethod(type) {
    return function (options) {
        return Toast(_extends({
            type: type
        }, parseOptions(options)));
    };
};

['loading', 'success', 'fail'].forEach(function (method) {
    Toast[method] = createMethod(method);
});

Toast.clear = function (all) {
    if (queue.length) {
        if (all) {
            queue.forEach(function (toast) {
                toast.clear();
            });
            queue = [];
        } else if (!multiple) {
            queue[0].clear();
        } else {
            queue.shift().clear();
        }
    }
};

Toast.setDefaultOptions = function (type, options) {
    if (typeof type === 'string') {
        defaultOptionsMap[type] = options;
    } else {
        _extends(currentOptions, type);
    }
};

Toast.resetDefaultOptions = function (type) {
    if (typeof type === 'string') {
        defaultOptionsMap[type] = null;
    } else {
        currentOptions = _extends({}, defaultOptions);
        defaultOptionsMap = {};
    }
};

Toast.allowMultiple = function () {
    var value = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

    multiple = value;
};

Toast.install = function () {
    Vue.use(VueToast);
};

Vue.prototype.$toast = Toast;

export default Toast;