'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.on = on;
exports.off = off;
exports.stopPropagation = stopPropagation;
exports.preventDefault = preventDefault;
var supportsPassive = exports.supportsPassive = false;

try {
    var opts = {};
    Object.defineProperty(opts, 'passive', {
        // eslint-disable-next-line getter-return
        get: function get() {
            /* istanbul ignore next */
            exports.supportsPassive = supportsPassive = true;
        }
    });
    window.addEventListener('test-passive', null, opts);
    // eslint-disable-next-line no-empty
} catch (e) {}

function on(target, event, handler) {
    var passive = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

    target.addEventListener(event, handler, supportsPassive ? {
        capture: false,
        passive: passive
    } : false);
}

function off(target, event, handler) {
    target.removeEventListener(event, handler);
}

function stopPropagation(event) {
    event.stopPropagation();
}

function preventDefault(event, isStopPropagation) {
    /* istanbul ignore else */
    if (typeof event.cancelable !== 'boolean' || event.cancelable) {
        event.preventDefault();
    }

    if (isStopPropagation) {
        stopPropagation(event);
    }
}