'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _icon = require('../icon');

var _icon2 = _interopRequireDefault(_icon);

var _carousel = require('../carousel');

var _carousel2 = _interopRequireDefault(_carousel);

var _pickerView = require('../picker-view');

var _pickerView2 = _interopRequireDefault(_pickerView);

var _util = require('../calendar/util');

var _dateUtil = require('../utils/dateUtil');

var _numberUtil = require('../utils/numberUtil');

var _event = require('../_utils/dom/event');

var _raf = require('../_utils/dom/raf');

require('./index.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var CarouselItem = _carousel2['default'].Item;

var DateTimePickerView = {
    name: "SnDatetimePickerView",
    data: function data() {
        return {
            height: 0,
            panelTitle: '',
            times: [],
            selectedDate: [],
            selectedTime: [],
            weekList: ["日", "一", "二", "三", "四", "五", "六"],
            yearAndMonthList: [],
            showCalender: true,
            showMonthSelect: false,
            showTimeSelect: false,
            year: 0,
            month: 0,
            today: (0, _dateUtil.dateFormat)(new Date(), 'YYYY/MM/DD'),
            currentValue: '',
            currentDate: '',
            currentTime: "08:30",
            swiperList: [],
            swiperItemIndex: 0,
            quickToday: true,
            minDate: false,
            maxDate: false
        };
    },

    props: {
        value: [String, Number, Array, Date],
        /* 时间控件模式
        * 1) 'date':         选择日期
        * 2) 'datetime':     选择时间
        * 3) 'year-month':   选择年月
        * 4） 'year':        选择年份
        * 5） 'month':       选择月份
        * 6)  'time':        选择时分
        * */
        mode: { 'default': "date" },
        disabledDate: Function
    },
    computed: {
        styleHeight: function styleHeight() {
            return this.height + 'px';
        }
    },
    created: function created() {
        this.currentValue = this.value;
        var mode = this.mode;
        var date = this.currentValue && new Date(this.currentValue) || new Date();
        var year = date.getFullYear(),
            month = date.getMonth();
        var fullYear = '' + year,
            fullMonth = (0, _numberUtil.zeroComplete)(month + 1);
        if (mode === 'date') {
            this.currentValue = (0, _dateUtil.dateFormat)(date, 'YYYY/MM/DD');
            this.quickToday = true;
            this.selectedDate = [fullYear, fullMonth];
            this.render(year, month);
            this.renderYearAndMonth(year, month);
        } else if (mode === 'datetime') {
            try {
                this.currentDate = (0, _dateUtil.dateFormat)(date, 'YYYY/MM/DD');
            } catch (e) {
                throw Error('[dateTimePickerView] 时间格式不正确');
            }
            this.currentValue = (0, _dateUtil.dateFormat)(date, 'YYYY/MM/DD');
            this.quickToday = false;
            this.selectedDate = [fullYear, fullMonth];
            this.render(year, month);
            this.renderYearAndMonth(year, month);
            this.renderTime(date.getHours(), date.getMinutes());
        } else if (mode === 'year-month') {
            this.showCalender = false;
            this.showMonthSelect = true;
            this.quickToday = false;
            this.selectedDate = [fullYear, fullMonth];
            this.renderYearAndMonth(year, month);
        } else if (mode === 'year') {
            this.showCalender = false;
            this.showMonthSelect = true;
            this.quickToday = false;
            this.selectedDate = [fullYear];
            this.renderYearAndMonth(year);
        } else if (mode === 'month') {
            this.showCalender = false;
            this.showMonthSelect = true;
            this.quickToday = false;
            this.selectedDate = [fullMonth];
            this.renderYearAndMonth(null, month);
        } else if (mode === 'time') {
            this.showCalender = false;
            this.showMonthSelect = false;
            this.quickToday = false;
            this.showTimeSelect = true;
            if (this.currentValue) {
                if (this.currentValue instanceof Array) {
                    this.renderTime(this.currentValue[0], this.currentValue[1]);
                } else {
                    console.error("[sinosun-ui] DatetimePickerView 模式为time时，value值必须为数组。");
                }
            } else {
                this.renderTime(date.getHours(), date.getMinutes());
            }
        }

        /* 动态计算swiper高度 */
        this.getHeight();
    },
    mounted: function mounted() {
        if (["year-month", "year", "month"].indexOf(this.mode) > -1) {
            this.$refs.datePicker.setValues(this.selectedDate);
        }
        if (["time"].indexOf(this.mode) > -1) {
            this.$refs.timePicker.setValues(this.selectedTime);
        }
    },

    methods: {
        /* 获取高度 */
        getHeight: function getHeight() {
            var windowWidth = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;
            this.height = windowWidth < 480 ? windowWidth * .94 : 360;
            // console.log('this.height == ', this.height);
        },

        /* 渲染入口 */
        render: function render(year, month) {
            var force = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

            var value = this.currentValue;
            // if (this.year === year && this.month === month && !force) {
            //     return;
            // }
            this.year = year;
            this.month = month;

            /* 注入滑动数组 */
            this.renderCarousel(year, month, value);
        },

        /* 渲染单页两个月数据 */
        renderCarousel: function renderCarousel(year, month, value) {
            var disabledDate = this.disabledDate;

            /* 生成总共需要的四个月数据 */

            var prevTime = (0, _util.getPrevTime)(year, month);
            var nextTime = (0, _util.getNextTime)(year, month);
            var prevMonth = (0, _util.getDays)((0, _extends3['default'])({}, prevTime, { value: value, disabledDate: disabledDate }));
            var curMonth = (0, _util.getDays)({ year: year, month: month, value: value, disabledDate: disabledDate });
            var nextMonth = (0, _util.getDays)((0, _extends3['default'])({}, nextTime, { value: value, disabledDate: disabledDate }));

            this.$refs.carousel && this.$refs.carousel.swipeTo(0);
            this.swiperList = [];
            this.swiperList = [curMonth, nextMonth, prevMonth];
        },

        /* 根据指定日期生成上下20年年月数据 */
        renderYearAndMonth: function renderYearAndMonth(year, month) {
            var mode = this.mode;
            var _date = new Date();
            var _year = _date.getFullYear();
            var yearList = [],
                monthList = [];
            // 加载前后20年数据
            for (var i = _year - 20; i <= _year + 20; i++) {
                yearList.push('' + i);
            }
            // 加载12个月份
            for (var _i = 1; _i <= 12; _i++) {
                var _month2 = (0, _numberUtil.zeroComplete)(_i);
                monthList.push('' + _month2);
            }

            if (mode === 'date' || mode === 'datetime' || mode === 'year-month') {
                this.yearAndMonthList = [{
                    values: yearList,
                    defaultIndex: 0
                }, {
                    values: monthList,
                    defaultIndex: 1
                }];
                this.selectedDate = ['' + year, '' + (0, _numberUtil.zeroComplete)(month + 1)];
            } else if (mode === 'year') {
                this.yearAndMonthList = [{ values: yearList }];
                this.selectedDate = ['' + year];
            } else if (mode === 'month') {
                this.yearAndMonthList = [{ values: monthList }];
                this.selectedDate = ['' + (0, _numberUtil.zeroComplete)(month + 1)];
            }
        },

        /* 渲染时分选择 */
        renderTime: function renderTime(hour, min) {
            var now = new Date();

            var hours = [];
            var minutes = [];
            for (var i = 0; i < 60; i++) {
                if (i < 24) {
                    hours.push('' + (0, _numberUtil.zeroComplete)(i));
                }
                minutes.push('' + (0, _numberUtil.zeroComplete)(i));
            }
            this.times = [{
                values: hours,
                defaultIndex: 0
            }, {
                values: minutes,
                defaultIndex: 1
            }];
            this.selectedTime = [(0, _numberUtil.zeroComplete)(!isNaN(hour) ? hour : now.getHours()), (0, _numberUtil.zeroComplete)(!isNaN(min) ? min : now.getMinutes())];
            this.currentTime = this.selectedTime.join(':');
        },

        /* 上一页 */
        prev: function prev() {
            if (!this.minDate) {
                var swiperItemIndex = this.swiperItemIndex;
                var goIndex = swiperItemIndex - 1 >= 0 ? swiperItemIndex - 1 : 2;
                this.$refs.carousel.swipeTo(goIndex);
            }
        },

        /* 下一页 */
        next: function next() {
            if (!this.maxDate) {
                var swiperItemIndex = this.swiperItemIndex;
                var goIndex = swiperItemIndex + 1 <= 2 ? swiperItemIndex + 1 : 0;
                this.$refs.carousel.swipeTo(goIndex);
            }
        },

        /* 跳转页 */
        go: function go(year, month) {
            this.render(year, month, true);
        },

        /* 选择日期 */
        select: function select(event, k1, k2, data) {
            (0, _event.preventDefault)(event, true);
            var mode = this.mode;
            if (data.isDisabled) {
                return;
            }
            if (data.isLastMonth && !this.showLastMonth) {
                return;
            }
            if (data.isNextMonth && !this.showNextMonth) {
                return;
            }

            var _currentValue = data.formatedDate;
            if (!data.isLastMonth && !data.isNextMonth) {
                var index = this.swiperItemIndex;
                var month = this.swiperList[index];
                var days = month.days;
                for (var row = 0; row < days.length; row++) {
                    for (var day = 0; day < days[row].length; day++) {
                        if (row === k1 && day === k2) {
                            days[k1][k2].isCurrent = true;
                        } else {
                            days[row][day].isCurrent = false;
                        }
                    }
                }
            }
            this.currentValue = _currentValue;
            this.currentDate = _currentValue;
            if (mode === 'date') {
                this.$emit('change', this.currentValue);
            }

            if (this.renderOnValueChange) {
                this.render(null, null);
            }
        },

        /* 选择当天 */
        setToday: function setToday(event) {
            (0, _event.preventDefault)(event, true);
            var now = new Date();
            var year = now.getFullYear(),
                month = now.getMonth();
            this.swiperItemIndex = 0;
            this.$refs.carousel.swipeTo(0);
            this.currentValue = (0, _dateUtil.dateFormat)(now, 'YYYY/MM/DD');
            this.selectedDate = ['' + year, '' + (0, _numberUtil.zeroComplete)(month + 1)];
            this.render(year, month);
            console.log('setToday == before onChange == ', this.currentValue);
            this.$emit('change', this.currentValue);
        },

        /* 设置选中的天 */
        setSelectedDay: function setSelectedDay() {
            var currentDate = new Date(this.currentValue);
            var day = currentDate.getDate();
            /* 当前月最大日期 */
            var selectedMonthMaxDate = new Date(this.year, this.month + 1, 0).getDate();
            var selectedDay = (0, _dateUtil.dateFormat)(new Date(this.year, this.month, day < selectedMonthMaxDate ? day : selectedMonthMaxDate), 'YYYY/MM/DD');
            this.currentValue = selectedDay;
            this.currentDate = selectedDay;
            console.log('setSelectedDay currentValue = ', this.currentValue);
            for (var t = 0; t < this.swiperList.length; t++) {
                var month = this.swiperList[t];
                var days = month.days;
                for (var row = 0; row < days.length; row++) {
                    for (var _day = 0; _day < days[row].length; _day++) {
                        if (days[row][_day].formatedDate === selectedDay) {
                            this.swiperList[t].days[row][_day].isCurrent = true;
                        } else {
                            this.swiperList[t].days[row][_day].isCurrent = false;
                        }
                    }
                }
            }
        },

        /* 确认日期 */
        submit: function submit(event) {
            (0, _event.preventDefault)(event, true);
            var mode = this.mode;
            if (mode === 'datetime') {
                if (!this.currentDate || this.currentDate === '') {
                    this.$toast({
                        position: 'bottom',
                        message: '请选择日期'
                    });
                    return;
                    return;
                } else {
                    this.currentValue = this.currentDate + ' ' + this.currentTime;
                }
            } else if (mode === 'year-month') {
                this.currentValue = this.selectedDate;
            } else if (mode === 'year' || mode === 'month') {
                this.currentValue = this.selectedDate;
            } else if (mode === 'time') {
                this.currentValue = this.selectedTime;
            }
            console.log('submit value == ', this.currentValue);
            this.$emit('change', this.currentValue);
        },

        /* 日历onChange回调 */
        onCalendarChange: function onCalendarChange(currentIndex) {
            var _this = this;

            // console.log('onCalendarChange currentIndex === ', currentIndex);
            // console.log('onCalendarChange swiperItemIndex === ', this.swiperItemIndex);
            /* 滑动结束后执行选中滑动前选中的天 */
            if (currentIndex !== this.swiperItemIndex) {
                this.$nextTick(function () {
                    (0, _raf.doubleRaf)(function () {
                        var disabledDate = _this.disabledDate;

                        var _year = _this.year,
                            _month = _this.month,
                            _currentValue = _this.currentValue;

                        _this.year = _this.swiperList[currentIndex].year;
                        _this.month = _this.swiperList[currentIndex].month;
                        _this.selectedDate = ['' + _this.year, '' + (0, _numberUtil.zeroComplete)(_this.month + 1)];
                        var prevTime = (0, _util.getPrevTime)(_year, _month);
                        var prev2Time = (0, _util.getPrevTime)(prevTime.year, prevTime.month);
                        var nextTime = (0, _util.getNextTime)(_year, _month);
                        var next2Time = (0, _util.getNextTime)(nextTime.year, nextTime.month);
                        var next3Time = (0, _util.getNextTime)(next2Time.year, next2Time.month);

                        var prevMonth = (0, _util.getDays)((0, _extends3['default'])({}, prevTime, { value: _currentValue, disabledDate: disabledDate }));
                        var prev2Month = (0, _util.getDays)((0, _extends3['default'])({}, prev2Time, { value: _currentValue, disabledDate: disabledDate }));
                        var next2Month = (0, _util.getDays)((0, _extends3['default'])({}, next2Time, { value: _currentValue, disabledDate: disabledDate }));
                        var next3Month = (0, _util.getDays)((0, _extends3['default'])({}, next3Time, { value: _currentValue, disabledDate: disabledDate }));

                        /* 当前页为第一页 */
                        if (_this.swiperItemIndex === 0) {
                            /* 下滑，进入第二页; 开始顺序 => [cur, next, prev], 结束顺序 => [cur, next, next2] */
                            if (currentIndex === 1) {
                                _this.$set(_this.swiperList, 2, next2Month);
                            } else {
                                /* 上滑，进入第三页; 开始顺序 => [cur, next, prev], 结束顺序 => [cur, prev2, prev] */
                                _this.$set(_this.swiperList, 1, prev2Month);
                            }
                        }
                        /* 当前页为第二页 */
                        else if (_this.swiperItemIndex === 1) {
                                /* 下滑，进入第三页; 开始顺序 => [prev, cur, next], 结束顺序 => [next2, cur, next] */
                                if (currentIndex === 2) {
                                    _this.$set(_this.swiperList, 0, next2Month);
                                } else {
                                    /* 上滑，进入第一页; 开始顺序 => [prev, cur, next], 结束顺序 => [prev, cur, prev2] */
                                    _this.$set(_this.swiperList, 2, prev2Month);
                                }
                            }
                            /* 当前页为第三页 */
                            else if (_this.swiperItemIndex === 2) {
                                    /* 下滑，进入第一页; 开始顺序 => [next, prev, cur], 结束顺序 => [next, next2, cur] */
                                    if (currentIndex === 0) {
                                        _this.$set(_this.swiperList, 1, next2Month);
                                    } else {
                                        /* 上滑，进入第二页; 开始顺序 => [next, prev, cur], 结束顺序 => [prev2, prev, cur] */
                                        _this.$set(_this.swiperList, 0, prev2Month);
                                    }
                                }
                        _this.swiperItemIndex = currentIndex;

                        _this.setSelectedDay();
                    });
                });
            }
        },

        /* 年月onChange回调 */
        onYearAndMonthChange: function onYearAndMonthChange(picker, value, index) {
            console.log('onYearAndMonthChange = ', picker, value, index);
            this.selectedDate = value;
            if (value && value instanceof Array) {
                var mode = this.mode;

                if (mode === 'date' || mode === 'datetime' || mode === 'year-month') {
                    var year = value[0];
                    var month = value[1];

                    if (mode !== 'year-month') {
                        var day = new Date(this.currentValue).getDate();
                        /* 当前月最大日期 */
                        var selectedMonthMaxDate = new Date(year, month, 0).getDate();
                        var selectedDay = (0, _dateUtil.dateFormat)(new Date(year, month - 1, day < selectedMonthMaxDate ? day : selectedMonthMaxDate), 'YYYY/MM/DD');
                        this.currentValue = selectedDay;
                        this.currentDate = selectedDay;
                        this.render(parseInt(year), parseInt(month - 1), true);
                    }
                } else if (mode === 'year') {
                    var _year2 = value[0];
                    this.panelTitle = _year2 + '\u5E74';
                } else if (mode === 'month') {
                    var _month3 = value[0];
                    this.panelTitle = _month3 + '\u6708';
                }
            }
        },

        /* 时间onChange回调 */
        onTimeChange: function onTimeChange(picker, value, index) {
            this.selectedTime = value;
            this.currentTime = value[0] + ":" + value[1];
        },

        /* 切换视图 */
        onViewChange: function onViewChange(type) {
            if (this.mode === 'date' || this.mode === 'datetime') {
                if (this.showMonthSelect) {
                    this.showMonthSelect = false;
                    this.showCalender = true;
                } else if (this.showTimeSelect) {
                    this.showCalender = true;
                    this.showTimeSelect = false;
                } else {
                    this.showCalender = false;

                    if (type === "date") {
                        this.showMonthSelect = true;
                        this.$refs.datePicker.setValues(this.selectedDate);
                    } else if (type === "time") {
                        this.showTimeSelect = true;
                        this.$refs.timePicker.setValues(this.selectedTime);
                    }
                }
            }
        }
    },
    watch: {
        value: function value(val) {
            this.currentValue = val;
        },
        currentValue: function currentValue(val) {
            var mode = this.mode,
                currentValue = this.currentValue,
                selectedDate = this.selectedDate;

            if (mode === 'date' || mode === 'datetime' || mode === 'year-month') {
                var now = new Date();

                if (mode === 'date') {
                    this.panelTitle = (0, _dateUtil.dateFormat)(currentValue, 'YYYY年MM月DD日 EE');
                } else if (mode === 'datetime') {
                    this.panelTitle = (0, _dateUtil.dateFormat)(currentValue, 'YYYY年MM月DD日');
                } else {
                    this.panelTitle = selectedDate[0] + '\u5E74' + selectedDate[1] + '\u6708';
                }
            } else if (mode === 'year') {
                this.panelTitle = selectedDate[0] + '\u5E74';
            } else if (mode === 'month') {
                this.panelTitle = selectedDate[0] + '\u6708';
            }
        },
        selectedDate: function selectedDate(val) {
            var mode = this.mode;

            if (mode === 'date' || mode === 'datetime' || mode === 'year-month') {
                var now = new Date();

                if (parseInt(val[0]) === now.getFullYear() - 20 && parseInt(val[1]) === 1) {
                    this.minDate = true;
                }
                if (parseInt(val[0]) === now.getFullYear() + 20 && parseInt(val[1]) === 12) {
                    this.maxDate = true;
                }
            }
        },
        selectedTime: function selectedTime(val) {
            var mode = this.mode;

            if (mode === 'time') {
                this.panelTitle = val[0] + '\u65F6' + val[1] + '\u5206';
            }
        }
    },
    render: function render() {
        var _this2 = this;

        var h = arguments[0];
        var mode = this.mode,
            panelTitle = this.panelTitle,
            currentTime = this.currentTime,
            height = this.height,
            styleHeight = this.styleHeight,
            quickToday = this.quickToday,
            showMonthSelect = this.showMonthSelect,
            swiperList = this.swiperList,
            weekList = this.weekList,
            yearAndMonthList = this.yearAndMonthList,
            times = this.times,
            showCalender = this.showCalender,
            showTimeSelect = this.showTimeSelect;


        return h(
            'div',
            { 'class': 'sn-datetime-picker-view' },
            [h(
                'div',
                { 'class': 'sn-datetime-picker-view-header' },
                [h(
                    'div',
                    { 'class': 'sn-calendar-tabs' },
                    [h(
                        'div',
                        {
                            directives: [{
                                name: 'show',
                                value: showCalender && (mode === 'date' || mode === 'datetime')
                            }],

                            'class': 'sn-datetime-picker-view-tabs-arrow',
                            on: {
                                'click': this.prev
                            }
                        },
                        [h(_icon2['default'], {
                            attrs: { type: 'up' },
                            'class': 'arrow left' })]
                    ), h(
                        'div',
                        {
                            'class': {
                                'sn-datetime-picker-view-tabs-item': true,
                                active: (mode === 'date' || mode === 'datetime') && showMonthSelect
                            },
                            on: {
                                'click': function click() {
                                    return _this2.onViewChange('date');
                                }
                            }
                        },
                        [panelTitle]
                    ), h(
                        'div',
                        {
                            directives: [{
                                name: 'show',
                                value: showCalender && (mode === 'date' || mode === 'datetime')
                            }],

                            'class': 'sn-datetime-picker-view-tabs-arrow',
                            on: {
                                'click': this.next
                            }
                        },
                        [h(_icon2['default'], {
                            attrs: { type: 'up' },
                            'class': 'arrow right' })]
                    ), mode === 'datetime' ? h(
                        'div',
                        {
                            'class': {
                                "sn-datetime-picker-view-tabs-item": true,
                                "active": showTimeSelect,
                                'replace-arrow-seat': showMonthSelect || showTimeSelect
                            },
                            on: {
                                'click': function click() {
                                    return _this2.onViewChange('time');
                                }
                            }
                        },
                        [currentTime]
                    ) : null]
                ), h(
                    'div',
                    {
                        'class': 'sn-datetime-picker-view-btn',
                        directives: [{
                            name: 'show',
                            value: !quickToday && showCalender || ["year-month", "year", "month", "time"].indexOf(mode) > -1
                        }],
                        on: {
                            'click': this.submit
                        }
                    },
                    ['\u786E\u5B9A']
                ), quickToday && !showMonthSelect ? h(
                    'div',
                    { 'class': 'sn-datetime-picker-view-btn', on: {
                            'click': this.setToday
                        }
                    },
                    ['\u4ECA\u5929']
                ) : null, (mode === 'date' || mode === 'datetime') && !showCalender ? h(
                    'div',
                    { 'class': 'sn-datetime-picker-view-btn', on: {
                            'click': function click() {
                                return _this2.onViewChange(showMonthSelect ? 'date' : 'time');
                            }
                        }
                    },
                    ['\u786E\u5B9A']
                ) : null]
            ), h(
                'div',
                { 'class': 'sn-datetime-picker-view-weekday', style: { visibility: showCalender ? 'visible' : 'hidden' } },
                [weekList.map(function (week) {
                    return h(
                        'div',
                        { 'class': 'sn-datetime-picker-view-weekday-item' },
                        [h('div', [week])]
                    );
                })]
            ), h(
                'div',
                { 'class': 'sn-calendar', style: { height: styleHeight } },
                [h(
                    _carousel2['default'],
                    {
                        ref: 'carousel',
                        attrs: { 'show-indicators': false,

                            loop: true,
                            vertical: true
                        },
                        on: {
                            'change': this.onCalendarChange
                        },
                        directives: [{
                            name: 'show',
                            value: showCalender
                        }],

                        style: { height: styleHeight }
                    },
                    [swiperList.map(function (month, k0) {
                        return h(
                            CarouselItem,
                            { style: { width: '100%', height: styleHeight } },
                            [h('div', [h(
                                'div',
                                { 'class': 'sn-calendar-date' },
                                [month.year + '-' + month.month_str]
                            ), h(
                                'div',
                                { 'class': 'sn-calendar-month' },
                                [month.days.map(function (row, k1) {
                                    return h(
                                        'div',
                                        { 'class': 'month-row' },
                                        [row.map(function (item, k2) {
                                            return h(
                                                'div',
                                                { 'class': 'day' },
                                                [item.isCurMonth ? h(
                                                    'div',
                                                    { 'class': 'day-pack', on: {
                                                            'click': function click(event) {
                                                                return _this2.select(event, k1, k2, item);
                                                            }
                                                        }
                                                    },
                                                    [h(
                                                        'div',
                                                        { 'class': {
                                                                today: item.isToday,
                                                                active: item.isCurrent,
                                                                disabled: item.isDisabled
                                                            } },
                                                        [h(
                                                            'div',
                                                            { 'class': 'day-pack-cell' },
                                                            [h(
                                                                'div',
                                                                { 'class': 'header' },
                                                                [item.isToday ? h('span', ['\u4ECA']) : null]
                                                            ), h(
                                                                'div',
                                                                {
                                                                    'class': {
                                                                        "middle": true,
                                                                        isHoliday: item.isHoliday,
                                                                        hidden: item.dayHide
                                                                    }
                                                                },
                                                                [item.day]
                                                            )]
                                                        )]
                                                    )]
                                                ) : null]
                                            );
                                        })]
                                    );
                                })]
                            )])]
                        );
                    })]
                ), h(
                    'div',
                    {
                        'class': {
                            "date-select": true,
                            "single-col": mode === "year" || mode === "month"
                        },
                        directives: [{
                            name: 'show',
                            value: showMonthSelect
                        }],

                        style: { height: height }
                    },
                    [h(_pickerView2['default'], {
                        ref: 'datePicker',
                        attrs: { visibleItemCount: 7,
                            columns: yearAndMonthList
                        },
                        on: {
                            'change': this.onYearAndMonthChange
                        }
                    })]
                ), h(
                    'div',
                    {
                        'class': 'time-select',
                        directives: [{
                            name: 'show',
                            value: showTimeSelect
                        }],

                        style: { height: height }
                    },
                    [h(_pickerView2['default'], {
                        ref: 'timePicker',
                        attrs: { visibleItemCount: 7,
                            columns: times
                        },
                        on: {
                            'change': this.onTimeChange
                        }
                    })]
                )]
            )]
        );
    }
};

exports['default'] = DateTimePickerView;
module.exports = exports.default;