'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _babelHelperVueJsxMergeProps = require('babel-helper-vue-jsx-merge-props');

var _babelHelperVueJsxMergeProps2 = _interopRequireDefault(_babelHelperVueJsxMergeProps);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _request = require('../upload/request');

var _request2 = _interopRequireDefault(_request);

var _jsBase = require('js-base64');

var _upload = require('../upload');

var _upload2 = _interopRequireDefault(_upload);

var _listItem = require('../mixins/list-item');

var _listItem2 = _interopRequireDefault(_listItem);

var _listItem3 = require('../list-item');

var _listItem4 = _interopRequireDefault(_listItem3);

var _toast = require('../toast');

var _toast2 = _interopRequireDefault(_toast);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

require('./spark-md5');


function URLSafeBase64Encode(data) {
    var base64Data = _jsBase.Base64.encode(data);
    return base64Data.replace(/\//g, '_').replace(/\+/g, '-');
}
function checkExist(value) {
    return !(value === null || value === undefined);
};

// 获取文件直接上传所需参数
function getUploadParam(file, option, direct_upload_obj) {
    if (checkExist(file.md5)) {
        direct_upload_obj.checksum = file.md5;
    }
    if (checkExist(option.anonymous)) {
        direct_upload_obj.anonymous = option.anonymous;
    }
    if (checkExist(option.encrypt)) {
        direct_upload_obj.encrypt = option.encrypt;
    }
    if (checkExist(option.imagePolicy)) {
        if (typeof option.imagePolicy === "string") {
            direct_upload_obj.imagePolicy = option.imagePolicy;
        } else {
            direct_upload_obj.imagePolicy = JSON.stringify(option.imagePolicy);
        }
    }
    var params_str = JSON.stringify(direct_upload_obj);
    return URLSafeBase64Encode(params_str);
};

// 获取文件分片上传所需参数
function getChunkUploadParam(fileId, chunkSeq, chunkSize, checkMd5) {
    var chunk_upload_obj = {
        fileUuid: fileId,
        chunkSeq: chunkSeq,
        chunkSize: chunkSize,
        token: mstpConf.mToken
    };

    if (checkExist(checkMd5)) {
        chunk_upload_obj.checksum = checkMd5;
    }
    var params_str = JSON.stringify(chunk_upload_obj);
    return URLSafeBase64Encode(params_str);
};

function getFileAndChunkMd5(file, isChunk) {
    var currentChunk = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;

    return new Promise(function (res, rej) {
        var blobSlice = File.prototype.slice || File.prototype.mozSlice || File.prototype.webkitSlice,
            spark = new SparkMD5.ArrayBuffer(),
            chunks = file.chunks,
            start = void 0,
            end = void 0,
            fileReader = new FileReader();

        fileReader.onload = function (e) {
            spark.append(e.target.result);
            if (isChunk) {
                var chunkBlob = blobSlice.call(file, start, end);
                var chunkSize = end - start;
                res({ chunkBlob: chunkBlob, md5: spark.end(), chunkSize: chunkSize });
            } else {
                if (currentChunk < chunks) {
                    currentChunk++;
                    readFileChunk();
                } else {
                    // spark.append(file.name); //如文件相同，名称不同,无法保留两个文件，需把文件名称加上。
                    var hash = spark.end();
                    res({ md5: hash });
                }
            }
        };

        fileReader.onerror = function (e) {
            console.log('[upload info]\u6587\u4EF6\u8BFB\u53D6\u5931\u8D25\u503C');
            rej(e);
        };

        var readFileChunk = function readFileChunk() {
            start = (currentChunk - 1) * mstpConf.chunkSize;
            end = start + mstpConf.chunkSize > file.size ? file.size : start + mstpConf.chunkSize;
            fileReader.readAsArrayBuffer(blobSlice.call(file, start, end));
        };

        readFileChunk();
    })['catch'](function (err) {
        console.log('[upload info] ' + err);
    });
}

var mstpConf = {
    chunkSize: 4 << 20,
    anonymous: 1
};
var mstp = {
    init: function init(option) {
        mstpConf.mAppId = option.appId;
        mstpConf.mMstpId = option.mstpId;
        mstpConf.mFsUrl = option.url;
        var tokenObj = {
            appId: option.appId,
            mstpId: option.mstpId,
            exptime: option.exptime,
            creationTime: option.creationTime,
            signature: option.signature
        };
        mstpConf.mToken = URLSafeBase64Encode(JSON.stringify(tokenObj));
    },
    uploadDeirect: function uploadDeirect(options) {
        getFileAndChunkMd5(options.file, false).then(function (data) {
            var md5 = data.md5,
                file = options.file;

            file.md5 = md5;
            var direct_upload_obj = {
                token: mstpConf.mToken,
                fileName: file.name,
                mstpId: mstpConf.mMstpId
            };
            var requestParams = {
                params: getUploadParam(file, options, direct_upload_obj) //to be set later
            };
            (0, _request2['default'])({
                action: mstpConf.mFsUrl + "/file/upload",
                data: requestParams,
                file: options.file,
                onProgress: options.onProgress,
                onSuccess: options.onSuccess,
                onError: options.onError
            });
        });
    },
    uploadChunk: function uploadChunk(file, options) {
        getFileAndChunkMd5(file, true, file.currentChunk).then(function (data) {
            var chunkBlob = data.chunkBlob,
                md5 = data.md5,
                chunkSize = data.chunkSize;

            var requestParams = {
                params: getChunkUploadParam(file.uid, file.currentChunk, chunkSize, md5), //to be set later
                chunk: file.currentChunk - 1,
                chunks: file.chunks
            };
            (0, _request2['default'])({
                action: mstpConf.mFsUrl + "/file/chunk/upload",
                data: requestParams,
                file: chunkBlob,
                onProgress: options.onProgress,
                onSuccess: options.onSuccess,
                onError: options.onError
            });
        }, function (e) {
            console.log('[upload info] e');
        });
    },
    mergeChunks: function mergeChunks(file, options, vm) {
        var direct_upload_obj = {
            fileUuid: file.uid,
            chunkCount: file.chunks,
            token: mstpConf.mToken,
            fileName: file.name,
            mstpId: mstpConf.mMstpId,
            anonymous: 1
        };
        var requestParams = {
            params: getUploadParam(file, options, direct_upload_obj)
        };
        (0, _request2['default'])({
            action: mstpConf.mFsUrl + "/file/chunk/merge",
            data: requestParams,
            headers: { 'content-Type': 'application/x-www-form-urlencoded' },
            onProgress: options.onProgress,
            onSuccess: function onSuccess() {
                vm.$emit('onSuccess', file);
            },
            onError: options.onError
        });
    },
    upload: function upload(options) {
        var chunkSize = mstpConf.chunkSize;
        var file = options.file;
        if (!file || !file.size || file.size <= 0 || !file.name) {
            console.log('[upload info] \u6587\u4EF6\u540D\u79F0\u6216\u8005\u6587\u4EF6\u683C\u5F0F\u975E\u6CD5\uFF0C\u8BF7\u786E\u8BA4\u6587\u4EF6\u540D\u6CA1\u6709\u7279\u6B8A\u5B57\u7B26\u6216\u8005\u6587\u4EF6\u540D\u8D85\u957F');
            return;
        }
        console.log('[upload info] start to upload file ' + file.name + ', file.size:', file.size, 'chunkSize:', chunkSize);
        if (file.size < chunkSize) {
            mstp.uploadDeirect(options);
        } else {
            file.chunks = Math.ceil(file.size / chunkSize);
            getFileAndChunkMd5(options.file, false).then(function (data) {
                var md5 = data.md5;

                file.md5 = md5;
                file.currentChunk = 1;
                mstp.uploadChunk(options.file, options);
            });
        }
    }
};

exports['default'] = {
    mixins: [_listItem2['default']],
    props: {
        rightIcon: {
            type: String,
            'default': 'clip-add'
        },
        listType: {
            type: String,
            'default': 'text'
        }, // or pictrue
        disabled: {
            type: Boolean,
            'default': false
        },
        uploadBefore: Function,
        succFunction: Function,
        showUploadList: {
            type: Boolean,
            'default': true
        },
        defaultFileList: {
            type: Array,
            'default': function _default() {
                return [];
            }
        },
        initOption: {
            appId: "433808474133",
            mstpId: "4563621431",
            exptime: '1592381275',
            creationTime: '1560845275',
            signature: "MGQEIGO1_lkeWNE7Mc5luQ74Q32kuATvFnVsgigLasmrJxr_BEBImrPRRQxvlvSZOBkoVLkVIx6t3kaLPXrzbnpDRXUKmxcs4Vkc-1eJccAzq9t7bD1j79G4smprak3srtg-tpCq",
            url: "https://mstpblackbox.sinosun.com"
        }
    },
    data: function data() {
        return {
            fileList: [].concat(this.defaultFileList)
        };
    },
    created: function created() {
        mstp.init(this.initOption);
    },

    methods: {
        reBeforeUpload: function reBeforeUpload() {
            if (!mstpConf.mToken) {
                this.$toast("请先初始化组件");
                return false;
            }
            if (!this.uploadBefore) {
                return true;
            }
            var result = this.uploadBefore(file, files);
            if (result === false) {
                return false;
            } else if (result && result.then) {
                return result;
            }
            return true;
        },
        onRightIconClick: function onRightIconClick() {
            this.$refs.Upload.onClick();
        }
    },
    render: function render() {
        var _this = this;

        var h = arguments[0];

        var uploadProps = {
            props: (0, _extends3['default'])({}, this.$props, {
                customRequest: mstp.upload,
                beforeUpload: this.reBeforeUpload
            }),
            on: {
                onStart: function onStart(file, fileList) {
                    _this.fileList.push(file);
                },
                onProgress: function onProgress(info, file) {
                    file.progress = parseInt(info.loaded / file.size * 100);
                    _this.$emit('onProgress', file);
                },
                onSuccess: function onSuccess(file) {
                    if (!file.chunks || file.chunks === 1) {
                        file.status = 'uploaded';
                        _this.$emit('onSuccess', file);
                        return;
                    }
                    if (file.currentChunk < file.chunks) {
                        file.currentChunk++;
                        mstp.uploadChunk(file, file.options);
                    } else {
                        mstp.mergeChunks(file, file.options, _this);
                    }
                },
                onPreview: function onPreview(file) {
                    _this.$emit("onPreview", file);
                }
            }
        };
        var itemProps = {
            props: {
                title: this.$props.title,
                rightIcon: this.$props.rightIcon,
                value: this.fileList.length ? this.fileList.length + '张' : '',
                valuePosition: 'left',
                labelNumber: 5
            }
        };

        return h(
            'div',
            { 'class': 'sn-mstp-upload' },
            [h(_listItem4['default'], (0, _babelHelperVueJsxMergeProps2['default'])([itemProps, {
                on: {
                    'right-icon-click': this.onRightIconClick
                }
            }])), this.$slots.top ? this.$slots.top : null, h(_upload2['default'], (0, _babelHelperVueJsxMergeProps2['default'])([uploadProps, { ref: 'Upload' }])), this.$slots.bottom ? this.$slots.bottom : null]
        );
    }
};
module.exports = exports.default;