'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _rangePickerView = require('../range-picker-view');

var _rangePickerView2 = _interopRequireDefault(_rangePickerView);

var _popup = require('../popup');

var _popup2 = _interopRequireDefault(_popup);

var _transferDom = require('../directives/transfer-dom');

var _transferDom2 = _interopRequireDefault(_transferDom);

var _commonUtil = require('../utils/commonUtil');

var _dateUtil = require('../utils/dateUtil');

require('./index.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var DatetimePicker = {
    name: "DateTimePicker",
    data: function data() {
        return {
            show: false,
            forceUpdate: false,
            currentValue: ''
        };
    },

    directives: { TransferDom: _transferDom2['default'] },
    props: {
        value: [String, Number, Array, Date],
        readonly: Boolean,
        mode: {
            type: String,
            'default': 'date'
        },
        displayFormat: {
            type: String,
            'default': 'YYYY/MM/DD'
        }
    },
    computed: {
        formatValue: function formatValue() {
            var currentValue = this.currentValue;

            return (0, _dateUtil.dateFormat)(new Date(currentValue[0]), 'YYYY/MM/DD') + ' - ' + (0, _dateUtil.dateFormat)(new Date(currentValue[1]), 'YYYY/MM/DD');
        }
    },
    created: function created() {
        this.currentValue = this.value || new Date();
    },
    mounted: function mounted() {},

    methods: {
        onInput: function onInput(val) {
            this.show = val;
        },
        onShow: function onShow() {
            this.$emit('show');
        },
        onHide: function onHide() {
            this.show = false;
            this.$emit('hide');
            // this.currentValue = this.value;
            // setTimeout(() => {
            //     this.forceUpdate = false;
            // }, 150);
        },
        onClick: function onClick() {
            var _this = this;

            if (!this.readonly) {
                var activeTagName = window.activeTagName || '';

                if (!(0, _commonUtil.isPC)() && activeTagName.toUpperCase() === 'INPUT' || activeTagName.toUpperCase() === 'TEXTAREA') {
                    setTimeout(function () {
                        _this.show = true;
                        _this.forceUpdate = true;
                    }, 300);
                } else {
                    this.show = true;
                    this.forceUpdate = true;
                }
            }
        },
        onChange: function onChange(val) {
            var _this2 = this;

            console.log('range-picker  onChange == ', val);
            if (!this.$listeners['change']) {
                this.$emit('input', val);
            }

            this.show = false;
            setTimeout(function () {
                _this2.forceUpdate = false;
            }, 150);
            this.$emit('change', val);
        }
    },
    watch: {
        value: function value(newVal, oldVal) {
            this.currentValue = newVal;
        }
    },
    render: function render() {
        var h = arguments[0];
        var currentValue = this.currentValue,
            formatValue = this.formatValue,
            forceUpdate = this.forceUpdate,
            show = this.show;


        return h(
            'div',
            { 'class': 'sn-range-picker', on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-range-picker-value' },
                [formatValue]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'transfer-dom',
                        value: true
                    }]
                },
                [h(
                    _popup2['default'],
                    {
                        attrs: { value: show },
                        on: {
                            'input': this.onInput,
                            'click-overlay': this.onHide
                        }
                    },
                    [forceUpdate ? h(_rangePickerView2['default'], {
                        attrs: {
                            value: currentValue
                        },
                        on: {
                            'change': this.onChange
                        }
                    }) : null]
                )]
            )]
        );
    }
};

exports['default'] = DatetimePicker;
module.exports = exports.default;