'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _icon = require('../icon');

var _icon2 = _interopRequireDefault(_icon);

require('./upload-list.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var imageTypes = ['image', 'webp', 'png', 'svg', 'gif', 'jpg', 'jpeg', 'bmp', 'ico'];


var previewFile = function previewFile(file, callback) {
    if (file.type) {
        var type = file.type.split("/")[0];
        if (!imageTypes.includes(type)) {
            return callback('');
        }
    }
    var reader = new window.FileReader();
    reader.onloadend = function () {
        callback(reader.result);
    };
    reader.readAsDataURL(file);
};

var isImage = function isImage(file) {
    if (file.type) {
        var type = file.type.split("/")[0];
        if (!imageTypes.includes(type)) {
            return false;
        } else {
            return true;
        }
    }
};

exports['default'] = {
    name: 'UploadList',
    components: {
        Icon: _icon2['default']
    },
    props: {
        items: {
            type: Array,
            'default': function _default() {
                return [];
            }
        },
        listType: {
            type: String
        }
    },
    data: function data() {
        return {
            prefixCls: 'sn-upload'
        };
    },
    updated: function updated() {
        var _this = this;

        this.$nextTick(function () {
            _this.items.map(function (file, index) {
                if (file.thumbUrl !== undefined) {
                    return;
                }
                previewFile(file.originFileObj, function (previewDataUrl) {
                    _this.$set(file, 'thumbUrl', previewDataUrl);
                });
            });
        });
    },

    methods: {
        handleRemove: function handleRemove(file, index) {
            this.$emit("remove", file, index);
        },
        handlePreview: function handlePreview(file, e) {
            var preview = this.$listeners.preview;

            if (!preview) {
                return;
            }
            e.preventDefault();
            return this.$emit('preview', file);
        }
    },
    render: function render() {
        var _this2 = this;

        var h = arguments[0];
        var _$props = this.$props,
            items = _$props.items,
            listType = _$props.listType;
        var prefixCls = this.$data.prefixCls;

        var listClassNames = [prefixCls + '-list', prefixCls + '-list-' + listType];

        var list = items.map(function (file, index) {
            var itemClassNames = [prefixCls + '-list-item', prefixCls + '-list-item-' + file.status];
            var thumbEl = isImage(file) ? h('img', {
                attrs: { src: file.thumbUrl || file.url }
            }) : h(_icon2['default'], {
                attrs: { type: 'file' }
            });
            return h(
                'div',
                { key: file.uid, 'class': itemClassNames },
                [h(_icon2['default'], {
                    attrs: { type: 'minus-circle-fill' },
                    'class': 'sn-upload-list-item-delete-icon', on: {
                        'click': function click(e) {
                            return _this2.handleRemove(file, e);
                        }
                    }
                }), h(
                    'div',
                    { 'class': 'sn-upload-list-item-con' },
                    [h(
                        'a',
                        {
                            attrs: { href: file.url || file.thumbUrl },
                            on: {
                                'click': function click(e) {
                                    return _this2.handlePreview(file, index);
                                }
                            }
                        },
                        [thumbEl]
                    ), h(
                        'div',
                        { 'class': 'sn-upload-list-item-info' },
                        [file.name]
                    )]
                )]
            );
        });
        return items.length ? h(
            'transition-group',
            {
                attrs: { tag: 'div' },
                'class': listClassNames },
            [list]
        ) : null;
    }
};
module.exports = exports.default;